<?php
/**
 * Functions
 *
 * @package     AutomatorWP\Advance_Custom_Fields\Functions
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Get acf fields related to posts
 *
 * @since 1.0.0
 *
 * @return array
 */
function automatorwp_advanced_custom_fields_options_cb_fields_posts( ) {

    $options = array(
        'any' => __( 'any field', 'automatorwp-pro' ),
    );
    
    // Get all post types
    $all_post_types = acf_get_post_types( );

    foreach ( $all_post_types as $post_type ) {

        $args_acf = array(
            'post_type' => $post_type,
        );

        // Get groups related to posts
        $all_post_groups = acf_get_field_groups( $args_acf );
        
        foreach( $all_post_groups as $group ) {
        
            // Get fields from group
            $all_acf_fields = acf_get_fields( $group['ID'] );

            foreach ( $all_acf_fields as $acf_fields ){

                $options[$acf_fields['name']] = $acf_fields['label'];
            }

        }

    }

    
    
    return $options;

}

/**
 * Get acf fields related to users
 *
 * @since 1.0.0
 *
 * @return array
 */
function automatorwp_advanced_custom_fields_options_cb_fields_users() {

    $options = array(
        'any' => __( 'any field', 'automatorwp-pro' ),
    );

    $all_user_groups = automatorwp_advanced_custom_fields_get_user_field_groups();
    
    foreach( $all_user_groups as $group ) {
    
        // Get fields from group
        $all_acf_fields = acf_get_fields( $group['ID'] );

        foreach ( $all_acf_fields as $acf_fields ){

            $options[$acf_fields['name']] = $acf_fields['label'];
        }

    }
    
    return $options;

}

/**
* Get all user field groups 
*
* @return array 
*/
function automatorwp_advanced_custom_fields_get_user_field_groups() {

	if ( ! function_exists( 'acf_get_field_groups' ) ) {
		return array();
	}

	$groups_user = array();

    // User location types
    $groups_user_types = array(
        'user_form',
        'current_user_role',
        'user_role',
        'current_user',
    );

	$groups = acf_get_field_groups();

	foreach ( $groups as $group ) {

		if ( ! empty( $group['location'] ) ) {

			foreach ( $group['location'] as $locations ) {

				foreach ( $locations as $location ) {

                    foreach ( $groups_user_types as $type ){

                        if ( $type === $location['param'] ) {

                            $groups_user[] = $group;
    
                        }

                    }

				}

			}

		}
        
	}

	return $groups_user;

}