<?php
/**
 * Generate Number
 *
 * @package     AutomatorWP\Integrations\Generator\Actions\Generate_Number
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly

if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_Generator_Generate_Number extends AutomatorWP_Integration_Action {

    public $integration = 'generator';
    public $action = 'generator_generate_number';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_action( $this->action, array(
            'integration'       => $this->integration,
            'label'             => __( 'Generate a random number', 'automatorwp-pro' ),
            'select_option'     => __( 'Generate a <strong>random number</strong>', 'automatorwp-pro' ),
            /* translators: %1$s: Random number. */
            'edit_label'        => sprintf( __( 'Generate a random %1$s', 'automatorwp-pro' ), '{random_number}' ),
            'log_label'         => sprintf( __( 'Generate a random %1$s', 'automatorwp-pro' ), '{random_number}' ),
            'options'           => array(
                'random_number' => array(
                    'default' => __( 'number', 'automatorwp-pro' ),
                    'fields' => array(
                        'min' => array(
                            'name' => __( 'Min value:', 'automatorwp-pro' ),
                            'desc' => __( 'The minimum value.', 'automatorwp-pro' ),
                            'type' => 'text',
                            'attributes' => array(
                                'type'  => 'number',
                                'min'   => 0
                            ),
                            'default' => 0
                        ),
                        'max' => array(
                            'name' => __( 'Max value:', 'automatorwp-pro' ),
                            'desc' => __( 'The maximum value.', 'automatorwp-pro' ),
                            'type' => 'text',
                            'attributes' => array(
                                'type'  => 'number',
                                'min'   => 1
                            ),
                            'default' => 999999
                        ),
                     ) )
            ),
            'tags'  => function_exists( 'automatorwp_generator_get_actions_random_number_tags' ) ? automatorwp_generator_get_actions_random_number_tags() : array(),
        ) );

    }

    /**
     * Action execution function
     *
     * @since 1.0.0
     *
     * @param stdClass  $action             The action object
     * @param int       $user_id            The user ID
     * @param array     $action_options     The action's stored options (with tags already passed)
     * @param stdClass  $automation         The action's automation object
     */
    public function execute( $action, $user_id, $action_options, $automation ) {

        // Shorthand
        $min = $action_options['min'];
        $max = $action_options['max'];
        
        $this->result = '';
       
        $this->random_number = mt_rand( $min , $max ); 
        
        $this->result = sprintf( __( 'Random number created: %d', 'automatorwp-pro' ), $this->random_number );

    }

    /**
     * Register required hooks
     *
     * @since 1.0.0
     */
    public function hooks() {

        // Configuration notice
        add_filter( 'automatorwp_automation_ui_after_item_label', array( $this, 'configuration_notice' ), 10, 2 );
		
		// Admin notice
		add_action( 'admin_notices', array( $this, 'admin_notice' ) );

        // Log meta data
        add_filter( 'automatorwp_user_completed_action_log_meta', array( $this, 'log_meta' ), 10, 5 );

        // Log fields
        add_filter( 'automatorwp_log_fields', array( $this, 'log_fields' ), 10, 5 );

        parent::hooks();

    }

    /**
     * Configuration notice
     *
     * @since 1.0.0
     *
     * @param stdClass  $object     The trigger/action object
     * @param string    $item_type  The object type (trigger|action)
     */
    public function configuration_notice( $object, $item_type ) {

        // Bail if action type don't match this action
        if( $item_type !== 'action' ) {
            return;
        }

        if( $object->type !== $this->action ) {
            return;
        }

        // Warn user if file was deleted
        if( ! function_exists( 'automatorwp_generator_get_actions_random_number_tags' ) ) : ?>
            <div class="automatorwp-notice-warning" style="margin-top: 10px; margin-bottom: 0;">
                <?php echo 
                    __( 'The generate a random number function was not found and may have been accidentally removed by a security plugin on your site.<br>', 'automatorwp-pro' ); ?>
                <?php echo
                    __( 'Please report this to the security plugin to add an exception to AutomatorWP and reinstall AutomatorWP to restore the deleted code.', 'automatorwp-pro' ); ?>
            </div>
        <?php endif;

    }
	
	 /**
     * Configuration notice
     *
     * @since 1.0.0
     *
     */
    public function admin_notice( ) {
		
		// Warn user if file was deleted
        if( ! function_exists( 'automatorwp_generator_get_actions_random_number_tags' ) ) : ?>
            <div id="message-error" class="notice notice-error is-dismissible">
            <?php echo 
                    __( '<strong>AutomatorWP found an issue:</strong><br>', 'automatorwp' ); ?>
                <?php echo 
                    __( 'The generate a random number function was not found and may have been accidentally removed by a security plugin on your site.<br>', 'automatorwp-pro' ); ?>
                <?php echo
                    __( 'Please report this to the security plugin to add an exception to AutomatorWP and reinstall AutomatorWP to restore the deleted code.', 'automatorwp-pro' ); ?>
            </div>
        <?php endif;

    }

    /**
     * Action custom log meta
     *
     * @since 1.0.0
     *
     * @param array     $log_meta           Log meta data
     * @param stdClass  $action             The action object
     * @param int       $user_id            The user ID
     * @param array     $action_options     The action's stored options (with tags already passed)
     * @param stdClass  $automation         The action's automation object
     *
     * @return array
     */
    public function log_meta( $log_meta, $action, $user_id, $action_options, $automation ) {

        // Bail if action type don't match this action
        if( $action->type !== $this->action ) {
            return $log_meta;
        }

        // Store the action's result
        $log_meta['result'] = $this->result;
        $log_meta['random_number'] = ( isset( $this->random_number ) ? $this->random_number : '' );

        return $log_meta;
    }

    /**
     * Action custom log fields
     *
     * @since 1.0.0
     *
     * @param array     $log_fields The log fields
     * @param stdClass  $log        The log object
     * @param stdClass  $object     The trigger/action/automation object attached to the log
     *
     * @return array
     */
    public function log_fields( $log_fields, $log, $object ) {

        // Bail if log is not assigned to an action
        if( $log->type !== 'action' ) {
            return $log_fields;
        }

        // Bail if action type don't match this action
        if( $object->type !== $this->action ) {
            return $log_fields;
        }

        $log_fields['result'] = array(
            'name' => __( 'Result:', 'automatorwp-pro' ),
            'type' => 'text',
        );

        return $log_fields;
    }

}

new AutomatorWP_Generator_Generate_Number();