<?php
/**
 * Ajax Functions
 *
 * @package     AutomatorWP\Link\Ajax_Functions
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Link click listener
 *
 * @since 1.0.0
 */
function automatorwp_ajax_link_click() {
    // Security check, forces to die if not security passed
    check_ajax_referer( 'automatorwp_link', 'nonce' );

    // Bail if not trigger provided
    if( ! isset( $_POST['trigger'] ) ) {
        wp_send_json_error( __( 'Invalid trigger.', 'automatorwp-pro' ) );
    }

    // Setup vars
    $trigger_id = absint( $_POST['trigger'] );
    $url        = isset( $_POST['url'] )         ? sanitize_text_field( $_POST['url'] ) : '';
    $id         = isset( $_POST['id'] )         ? sanitize_text_field( $_POST['id'] ) : '';
    $class      = isset( $_POST['class'] )      ? sanitize_text_field( $_POST['class'] ) : '';
    $post_id    = isset( $_POST['post_id'] )    ? absint( $_POST['post_id'] ) : 0;
    $user_id    = get_current_user_id();

    /**
     * Trigger link click action
     *
     * @since 1.0.0
     *
     * @param int       $trigger_id     The trigger ID
     * @param int       $user_id        The user ID
     * @param int       $post_id        The post ID
     * @param string    $url            The link url
     * @param string    $id             The link id attribute
     * @param string    $class          The link class attribute
     */
    do_action( 'automatorwp_link_clicked', $trigger_id, $user_id, $post_id, $url, $id, $class );

    wp_send_json_success( __( 'Done!', 'automatorwp-pro' ) );
    exit;
}
add_action( 'wp_ajax_automatorwp_link_click', 'automatorwp_ajax_link_click' );
