<?php
/**
 * Plugin Name:           AutomatorWP - MasterStudy LMS
 * Plugin URI:            https://automatorwp.com/add-ons/masterstudy-lms/
 * Description:           Connect AutomatorWP with MasterStudy LMS.
 * Version:               1.0.5
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-masterstudy-lms
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.7
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\MasterStudy_LMS
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_MasterStudy_LMS {

    /**
     * @var         AutomatorWP_MasterStudy_LMS $instance The one true AutomatorWP_MasterStudy_LMS
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_MasterStudy_LMS self::$instance The one true AutomatorWP_MasterStudy_LMS
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_MasterStudy_LMS();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();            
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_MASTERSTUDY_LMS_VER', '1.0.5' );

        // Plugin file
        define( 'AUTOMATORWP_MASTERSTUDY_LMS_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_MASTERSTUDY_LMS_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_MASTERSTUDY_LMS_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Triggers
            require_once AUTOMATORWP_MASTERSTUDY_LMS_DIR . 'includes/triggers/complete-quiz.php';
            require_once AUTOMATORWP_MASTERSTUDY_LMS_DIR . 'includes/triggers/complete-lesson.php';
            require_once AUTOMATORWP_MASTERSTUDY_LMS_DIR . 'includes/triggers/enroll-course.php';
            require_once AUTOMATORWP_MASTERSTUDY_LMS_DIR . 'includes/triggers/complete-course.php';
            require_once AUTOMATORWP_MASTERSTUDY_LMS_DIR . 'includes/triggers/download-certificate.php';

            // Actions
            require_once AUTOMATORWP_MASTERSTUDY_LMS_DIR . 'includes/actions/user-course.php';
            require_once AUTOMATORWP_MASTERSTUDY_LMS_DIR . 'includes/actions/mark-quiz.php';
            require_once AUTOMATORWP_MASTERSTUDY_LMS_DIR . 'includes/actions/mark-lesson.php';
            require_once AUTOMATORWP_MASTERSTUDY_LMS_DIR . 'includes/actions/mark-course.php';
            require_once AUTOMATORWP_MASTERSTUDY_LMS_DIR . 'includes/actions/reset-course-progress.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );
        
        

        
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'masterstudy_lms', array(
            'label' => 'MasterStudy LMS',
            'icon'  => AUTOMATORWP_MASTERSTUDY_LMS_URL . 'assets/masterstudy-lms.svg',
        ) );

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! defined( 'STM_LMS_FILE' ) ) {
            return false;
        }

        return true;

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_MasterStudy_LMS instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_MasterStudy_LMS The one true AutomatorWP_MasterStudy_LMS
 */
function AutomatorWP_MasterStudy_LMS() {
    return AutomatorWP_MasterStudy_LMS::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_MasterStudy_LMS' );
