<?php
/**
 * Get React Photo
 *
 * @package     AutomatorWP\Integrations\PeepSo\Triggers\Get_React_Photo
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_PeepSo_Get_React_Photo extends AutomatorWP_Integration_Trigger {

    public $integration = 'peepso';
    public $trigger = 'peepso_get_react_photo';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_trigger( $this->trigger, array(
            'integration'       => $this->integration,
            'label'             => __( 'User gets a react/unreact on an activity post with a photo', 'automatorwp-pro' ),
            'select_option'     => __( 'User <strong>gets a react/unreact</strong> on an activity post with a photo', 'automatorwp-pro' ),
            /* translators: %1$s: Operation (reacts or unreacts). %2$s: Number of times. */
            'edit_label'        => sprintf( __( 'User gets a %1$s on an activity post with a photo %2$s time(s)', 'automatorwp-pro' ), '{operation}', '{times}' ),
            /* translators: %1$s: Operation (reacts or unreacts). */
            'log_label'         => sprintf( __( 'User gets a %1$s on an activity post with a photo', 'automatorwp-pro' ), '{operation}' ),
            'action'            => array(
                'peepso_action_react_add',
                'peepso_action_react_remove',
            ),
            'function'          => array( $this, 'listener' ),
            'priority'          => 10,
            'accepted_args'     => 1,
            'options'           => array(
                'operation' => array(
                    'from' => 'operation',
                    'fields' => array(
                        'operation' => array(
                            'name' => __( 'Operation:', 'automatorwp-pro' ),
                            'type' => 'select',
                            'options' => array(
                                'react'       => __( 'react', 'automatorwp-pro' ),
                                'unreact'    => __( 'unreact', 'automatorwp-pro' ),
                            ),
                            'default' => 'react'
                        ),
                    )
                ),
                'times' => automatorwp_utilities_times_option(),
            ),
            'tags' => array_merge(
                automatorwp_utilities_times_tag()
            )
        ) );

    }

    /**
     * Trigger listener
     *
     * @since 1.0.0
     *
     * @param stdClass $data
     */
    public function listener( $data ) {

        $action = ( current_filter() === 'peepso_action_react_add' ? 'react' : 'unreact' );

        $user_id = $data->react_user_id;     // id of user adding the react
        $post_id = $data->react_external_id; // id of item being reactd; i.e. post_id
        $module_id = $data->react_module_id; // Defines from which module happens the react (0 from user profile, 1 from activity post or comment, etc)

        if( $module_id !== 4 ) {
            return;
        }

        $post_author = get_post_field( 'post_author', $post_id );

        // Trigger reacts
        automatorwp_trigger_event( array(
            'trigger'           => $this->trigger,
            'user_id'           => $post_author,
            'post_id'           => $post_id,
            'action'            => $action,
        ) );

    }

    /**
     * User deserves check
     *
     * @since 1.0.0
     *
     * @param bool      $deserves_trigger   True if user deserves trigger, false otherwise
     * @param stdClass  $trigger            The trigger object
     * @param int       $user_id            The user ID
     * @param array     $event              Event information
     * @param array     $trigger_options    The trigger's stored options
     * @param stdClass  $automation         The trigger's automation object
     *
     * @return bool                          True if user deserves trigger, false otherwise
     */
    public function user_deserves_trigger( $deserves_trigger, $trigger, $user_id, $event, $trigger_options, $automation ) {

        // Don't deserve if post is not received
        if( ! isset( $event['action'] ) ) {
            return false;
        }

        // Don't deserve if action doesn't match with the trigger option
        if( $trigger_options['operation'] !== $event['action'] ) {
            return false;
        }

        return $deserves_trigger;

    }

}

new AutomatorWP_PeepSo_Get_React_Photo();