<?php
/**
 * Plugin Name:           AutomatorWP - WPForms
 * Plugin URI:            https://automatorwp.com/add-ons/wpforms/
 * Description:           Connect AutomatorWP with WPForms.
 * Version:               1.0.5
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-wpforms
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          6.4
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\WPForms
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_WPForms {

    /**
     * @var         AutomatorWP_WPForms $instance The one true AutomatorWP_WPForms
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_WPForms self::$instance The one true AutomatorWP_WPForms
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_WPForms();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();            
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_WPFORMS_VER', '1.0.5' );

        // Plugin file
        define( 'AUTOMATORWP_WPFORMS_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_WPFORMS_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_WPFORMS_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Triggers
            require_once AUTOMATORWP_WPFORMS_DIR . 'includes/triggers/submit-form.php';
            require_once AUTOMATORWP_WPFORMS_DIR . 'includes/triggers/submit-field-value.php';
            // Anonymous Triggers
            require_once AUTOMATORWP_WPFORMS_DIR . 'includes/triggers/anonymous-submit-form.php';
            require_once AUTOMATORWP_WPFORMS_DIR . 'includes/triggers/anonymous-submit-field-value.php';

            // Includes
            require_once AUTOMATORWP_WPFORMS_DIR . 'includes/functions.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );
        
        

        
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'wpforms', array(
            'label' => 'WPForms',
            'icon'  => AUTOMATORWP_WPFORMS_URL . 'assets/wpforms.svg',
        ) );

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! function_exists( 'wpforms' ) ) {
            return false;
        }

        return true;

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_WPForms instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_WPForms The one true AutomatorWP_WPForms
 */
function AutomatorWP_WPForms() {
    return AutomatorWP_WPForms::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_WPForms' );
